@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # feed2mb
 # Copyright (C) 2009 EBC - Empresa Brasil de Comunicação
 #
@@ -30,9 +31,13 @@ def update(**kwargs):
     if not kwargs:
         opt = Options()
         options = opt.parse()
-        conf = MicroblogConfig(options.config_filename)
+
+        if options.show_version:
+	    global __version__
+            print(__version__)
+            sys.exit(1)
+
         if options.sample_config:
-            from pkg_resources import resource_string
             foo_config = resource_string(__name__, '../docs/default.cfg.sample')
             print(foo_config)
             sys.exit(1)
@@ -46,6 +51,8 @@ def update(**kwargs):
             logging.basicConfig(level=logging.DEBUG,
                     format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
             )
+
+        conf = MicroblogConfig(options.config_filename)
         configs = conf.configs()
     else:
         configs=[]
@@ -64,5 +71,5 @@ def update(**kwargs):
             log.debug('next ' + cf['service'] + ' update in: ' + str(interval) + ' seconds')
         time.sleep(interval)
 
-__version__ = '0.7.3'
+__version__ = '0.7.5'
 
