@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # feed2mb
 # Copyright (C) 2009 EBC - Empresa Brasil de Comunicação
 #
@@ -82,7 +83,7 @@ class WordpressAPI(object):
 
 class IdenticaAPI(Api):
 
-    _API_REALM = 'Laconica API'
+    _API_REALM = 'StatusNet API'
 
     def PostUpdate(self, text):
         import simplejson
